/*
 * Copyright (c) 2016 CA.  All rights reserved.
 *
 * This software and all information contained therein is confidential
 * and proprietary and shall not be duplicated, used, disclosed or
 * disseminated in any way except as authorized by the applicable
 * license agreement, without the express written permission of CA.
 * All authorized reproductions must be marked with this language.
 *
 * EXCEPT AS SET FORTH IN THE APPLICABLE LICENSE AGREEMENT, TO THE
 * EXTENT PERMITTED BY APPLICABLE LAW, CA PROVIDES THIS SOFTWARE
 * WITHOUT WARRANTY OF ANY KIND, INCLUDING WITHOUT LIMITATION, ANY
 * IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR
 * PURPOSE.  IN NO EVENT WILL CA BE LIABLE TO THE END USER OR ANY
 * THIRD PARTY FOR ANY LOSS OR DAMAGE, DIRECT OR INDIRECT, FROM THE
 * USE OF THIS SOFTWARE, INCLUDING WITHOUT LIMITATION, LOST PROFITS,
 * BUSINESS INTERRUPTION, GOODWILL, OR LOST DATA, EVEN IF CA IS
 * EXPRESSLY ADVISED OF SUCH LOSS OR DAMAGE.
 *
 */

package sample.restclient;

import static sample.restclient.JSON.gson;
import java.util.Map;

/**
 *
 * A Java representation for JSON objects of type "object".
 * Individual links in the 'links' field are represented as ObjectLinks
 *
 */

public class SmObject {
    private String     responseType;
  
    private ObjectLink parent;

    private ObjectData data;

    private Map<String, ObjectLink> links;

    private SmObject[]  children;

    public String getSelf(){
        ObjectLink self = links.get("self");
        return self.href;
    }


    @SuppressWarnings("unchecked")
    public <T> T  get(String key) {
        return (T) getData().get(key);
    }

    public void put(String key, Object val) {
        getData().put(key, val);
    }

    public String toJson() {
        return gson.toJson(this);
    }

    static public SmObject fromJson(String data) {
       return gson.fromJson(data, SmObject.class);
    }
    /**
     * @return the type
     */
    public String getResponseType() {
        return responseType;
    }

    
    /**
     * @return the parent
     */
    public ObjectLink getParent() {
        return parent;
    }

    /**
     * @return the data
     */
    public ObjectData getData() {
        if (data == null) {
            data = new ObjectData();
        }

        return data;
    }


    /**
     * @return the _links
     */
    public Map<String, ObjectLink> getLinks() {
        return links;
    }


    /**
     * @return the children
     */
    public SmObject[] getChildren() {
        return children;
    }
}
